@@ -1,7 +1,8 @@
 /*  GKrellMMS: GKrellM XMMS Plugin
- |  Copyright (C) 2000 Sander Klein Lebbink
+ |  Copyright (C) 2000-2002 Sander Klein Lebbink
  |
- |  Author:  Sander Klein Lebbink <sander@cerberus.demon.nl>
+ |  Original Author:  Sander Klein Lebbink <sander@cerberus.demon.nl>
+ |  Current Maintainer: Sjoerd Simons <sjoerd@luon.net>
  |  Latest versions might be found at:  http://gkrellm.luon.net/
  |
  |  This program is free software which I release under the GNU General Public
@@ -24,14 +25,18 @@ static GtkWidget *exec_entry,
                  *files_entry,
                  *playlist_dir_entry,
                  *label_entry,
+                 *separator_entry,
                  *session_entry,
                  *xmms_start_entry,
                  *scroll_enable_entry,
-                 *button_enable_entry,
                  *main_close_entry,
+                 *hide_all_entry,
                  *auto_play_entry,
                  *auto_seek_entry,
                  *draw_minus_entry,
+/*
+                 *scroll_command_entry,
+*/
                  *always_load_entry;
 
 static gint eject_thing;
@@ -47,28 +52,28 @@ void toggles_func (GtkWidget *w, gpointer what)
 
   switch (type)
   {
-    case mainwin:
+    case gkrellmms_mainwin:
       xmms_remote_main_win_toggle(xmms_session,
         !xmms_remote_is_main_win(xmms_session));
       break;
-    case playlist:
+    case gkrellmms_playlist:
       xmms_remote_pl_win_toggle(xmms_session,
         !xmms_remote_is_pl_win(xmms_session));
       break;
-    case eq:
+    case gkrellmms_eq:
       xmms_remote_eq_win_toggle(xmms_session,
         !xmms_remote_is_eq_win(xmms_session));
       break;
-    case repeat:
+    case gkrellmms_repeat:
       xmms_remote_toggle_repeat(xmms_session);
       break;
-    case shuffle:
+    case gkrellmms_shuffle:
       xmms_remote_toggle_shuffle(xmms_session);
       break;
-    case eject:
+    case gkrellmms_eject:
       xmms_remote_eject(xmms_session);
       break;
-    case prefs:
+    case gkrellmms_prefs:
       xmms_remote_show_prefs_box(xmms_session);
       break;
     default:
@@ -89,11 +94,36 @@ void save_playlist(gchar *, gint);
 void xmms_start_func ()
 {
   gchar *exec_this;
-  exec_this = g_strdup_printf("cd %s; %s > /dev/null 2>&1 &", files_directory, xmms_exec_command);
+  gchar *path;
+  gint timer;
+  time_t lt;
+
+  path = g_shell_quote(files_directory);
+  exec_this = 
+    g_strdup_printf("cd %s; %s > /dev/null 2>&1 &",path, xmms_exec_command);
+  g_free(path);
   if (system(exec_this))
-    gkrellm_message_window("GKrellMMS Error",
-      "Couldn't launch XMMS ;(", NULL);
+    gkrellm_message_window(_("GKrellMMS Error"),
+      _("Couldn't launch XMMS ;("), NULL);
   g_free(exec_this);
+
+	/*
+	 | wait until xmms has started, but no longer than 10 secs.
+	 | This is so that there are actually windows to hide when
+	 | we get to down to the auto_hide_all part.
+	 */
+  /* FIXME supposed ugly evil code */
+  timer = time(&lt);
+  while (!xmms_remote_is_running(xmms_session) && ((time(&lt) - timer) < 10))
+				usleep(0);
+
+	xmms_running = xmms_remote_is_running(xmms_session);
+
+	if (auto_hide_all && xmms_running) {
+    xmms_remote_main_win_toggle(xmms_session, FALSE);
+    xmms_remote_pl_win_toggle(xmms_session, FALSE);
+    xmms_remote_eq_win_toggle(xmms_session, FALSE);
+	}
 }
 
 void start_func (GtkWidget *w, gpointer data)
@@ -103,33 +133,18 @@ void start_func (GtkWidget *w, gpointer data)
 
 void quit_func (GtkWidget *w, gpointer data)
 {
-  gint timer;
+  time_t timer;
   time_t lt;
 
-/* Obsolete!
-  FILE *f;
-
-  save_playlist(playlist_file, 1);
-*/
-
   save_position(1);
   save_time(1);
 
-/* Obsolete!
-  f = popen("killall -TERM xmms", "r");
-  if (!f)
-    gkrellm_message_window("GKrellMMS Error",
-      "Couldn't kill XMMS ;(", NULL);
-  else
-    pclose(f);
-*/
-
-  timer = localtime(&lt)->tm_sec;
+  time(&lt);
+  timer = lt;
 
   xmms_remote_quit(xmms_session);
   while (xmms_remote_is_running(xmms_session)
-         && ((localtime(&lt)->tm_sec - timer) < 10))
-  {
+         && ((time(&lt) - timer) < 10)) {
     /* Do nothing; wait until xmms really quits, but not longer than 10sec! */
     usleep(0);
   }
@@ -139,61 +154,61 @@ void quit_func (GtkWidget *w, gpointer data)
 static GtkItemFactoryEntry gkrellmms_factory[] =
 {
   {"/-",                            NULL, NULL,          0,        "<Separator>"},
-  {"/Toggles...",                   NULL, NULL,          0,        "<Branch>"},
-  {"/Toggles.../Main Window",       NULL, toggles_func,  mainwin,  "<Item>"},
-  {"/Toggles.../Playlist",          NULL, toggles_func,  playlist, "<Item>"},
-  {"/Toggles.../EQ",                NULL, toggles_func,  eq,       "<Item>"},
-  {"/Toggles.../Repeat",            NULL, toggles_func,  repeat,   "<Item>"},
-  {"/Toggles.../Shuffle",           NULL, toggles_func,  shuffle,  "<Item>"},
-  {"/Toggles.../-",                 NULL, NULL,          0,        "<Separator>"},
-  {"/Toggles.../Always on top on",  NULL, aot_func,      ON,       "<Item>"},
-  {"/Toggles.../Always on top off", NULL, aot_func,      OFF,      "<Item>"},
+  {N_("/Toggles..."),                   NULL, NULL,          0,        "<Branch>"},
+  {N_("/Toggles.../Main Window"),       NULL, toggles_func,  gkrellmms_mainwin,  "<Item>"},
+  {N_("/Toggles.../Playlist"),          NULL, toggles_func,  gkrellmms_playlist, "<Item>"},
+  {N_("/Toggles.../EQ"),                NULL, toggles_func,  gkrellmms_eq,       "<Item>"},
+  {N_("/Toggles.../Repeat"),            NULL, toggles_func,  gkrellmms_repeat,   "<Item>"},
+  {N_("/Toggles.../Shuffle"),           NULL, toggles_func,  gkrellmms_shuffle,  "<Item>"},
+  {N_("/Toggles.../-"),                 NULL, NULL,          0,        "<Separator>"},
+  {N_("/Toggles.../Always on top on"),  NULL, aot_func,      ON,       "<Item>"},
+  {N_("/Toggles.../Always on top off"), NULL, aot_func,      OFF,      "<Item>"},
   {"/-",                            NULL, NULL,          0,        "<Separator>"},
   {"/Xmms...",                      NULL, NULL,          0,        "<Branch>"},
-  {"/Xmms.../Previous",             NULL, toggles_func,  prev,     "<Item>"},
-  {"/Xmms.../Play",                 NULL, toggles_func,  play,     "<Item>"},
-  {"/Xmms.../Pause",                NULL, toggles_func,  paus,     "<Item>"},
-  {"/Xmms.../Stop",                 NULL, toggles_func,  stop,     "<Item>"},
-  {"/Xmms.../Next",                 NULL, toggles_func,  next,     "<Item>"},
+  {N_("/Xmms.../Previous"),             NULL, toggles_func,  gkrellmms_prev,     "<Item>"},
+  {N_("/Xmms.../Play"),                 NULL, toggles_func,  gkrellmms_play,     "<Item>"},
+  {N_("/Xmms.../Pause"),                NULL, toggles_func,  gkrellmms_paus,     "<Item>"},
+  {N_("/Xmms.../Stop"),                 NULL, toggles_func,  gkrellmms_stop,     "<Item>"},
+  {N_("/Xmms.../Next"),                 NULL, toggles_func,  gkrellmms_next,     "<Item>"},
   {"/-",                            NULL, NULL,          0,        "<Separator>"},
-  {"/Playlist Editor",              NULL, pl_open_popup, 0,        "<Item>"},
+  {N_("/Playlist Editor"),              NULL, pl_open_popup, 0,        "<Item>"},
   {"/-",                            NULL, NULL,          0,        "<Separator>"},
-  {"/Open file(s)",                 NULL, toggles_func,  eject,    "<Item>"},
-  {"/Open Playlist",                NULL, pl_open_func,  0,        "<Item>"},
-  {"/XMMS Prefs",                   NULL, toggles_func,  prefs,    "<Item>"},
+  {N_("/Open file(s)"),                 NULL, toggles_func,  gkrellmms_eject,    "<Item>"},
+  {N_("/Open Playlist"),                NULL, pl_open_func,  0,        "<Item>"},
+  {N_("/XMMS Prefs"),                   NULL, toggles_func,  gkrellmms_prefs,    "<Item>"},
   {"/-",                            NULL, NULL,          0,        "<Separator>"},
-  {"/Quit XMMS",                    NULL, quit_func,     0,        "<Item>"},
+  {N_("/Quit XMMS"),                    NULL, quit_func,     0,        "<Item>"},
   {"/-",                            NULL, NULL,          0,        "<Separator>"},
 };
 
 static GtkItemFactoryEntry gkrellmms_factory_norun[] =
 {
   {"/-",                           NULL, NULL,          0,    "<Separator>"},
-  {"/Launch XMMS",                 NULL, start_func,    0,    "<Item>"},
+  {N_("/Launch XMMS"),                 NULL, start_func,    0,    "<Item>"},
   {"/-",                           NULL, NULL,          0,    "<Separator>"},
 };
 
 GtkItemFactory *options_menu_factory(gint run_menu)
 {
-  int n;
+  gint n,i;
   GtkItemFactory *music_factory;
   GtkAccelGroup  *axel;
   axel = gtk_accel_group_new();
 
-#if ((VERSION_MAJOR>1)||(VERSION_MAJOR==1 && VERSION_MINOR==1 && VERSION_REV>3)||(VERSION_MAJOR==1 && VERSION_MINOR>1))
   gtk_window_add_accel_group(GTK_WINDOW(gkrellm_get_top_window()), axel);
-#else
-  gtk_window_add_accel_group(GTK_WINDOW(top_window), axel);
-#endif
 
   music_factory = gtk_item_factory_new(GTK_TYPE_MENU, "<Main>", axel);
 
   if (run_menu)
   {
     n = sizeof(gkrellmms_factory) / sizeof(GtkItemFactoryEntry);
+    for(i = 0; i < n; i++)
+        gkrellmms_factory[i].path = _(gkrellmms_factory[i].path);
     gtk_item_factory_create_items(music_factory, n, gkrellmms_factory, NULL);
   } else {
     n = sizeof(gkrellmms_factory_norun) / sizeof(GtkItemFactoryEntry);
+    for(i = 0; i < n; i++)
+        gkrellmms_factory_norun[i].path = _(gkrellmms_factory_norun[i].path);
     gtk_item_factory_create_items(music_factory, n, gkrellmms_factory_norun, NULL);
   }
 
@@ -212,8 +227,7 @@ void options_menu(GdkEventButton *ev)
 
 void apply_gkrellmms_config()
 {
-  gint prev_scroll_enable,
-       prev_buttons_enable;
+  gint prev_scroll_enable;
 
   /* Entry's */
   g_free(xmms_exec_command);
@@ -228,15 +242,17 @@ void apply_gkrellmms_config()
   g_free(gkrellmms_label);
   gkrellmms_label = g_strdup(gtk_entry_get_text(GTK_ENTRY(label_entry)));
 
+  g_free(scroll_separator);
+  scroll_separator = g_strdup(gtk_entry_get_text(GTK_ENTRY(separator_entry)));
+
   xmms_session = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(session_entry));
 
   /* Toggles */
   prev_scroll_enable = scroll_enable;
-  prev_buttons_enable = buttons_enable;
   scroll_enable = GTK_TOGGLE_BUTTON(scroll_enable_entry)->active;
-  buttons_enable = GTK_TOGGLE_BUTTON(button_enable_entry)->active;
   xmms_autostart = GTK_TOGGLE_BUTTON(xmms_start_entry)->active;
   auto_main_close = GTK_TOGGLE_BUTTON(main_close_entry)->active;
+  auto_hide_all = GTK_TOGGLE_BUTTON(hide_all_entry)->active;
   auto_play_start = GTK_TOGGLE_BUTTON(auto_play_entry)->active;
   auto_seek = GTK_TOGGLE_BUTTON(auto_seek_entry)->active;
   draw_minus = GTK_TOGGLE_BUTTON(draw_minus_entry)->active;
@@ -247,25 +263,21 @@ void apply_gkrellmms_config()
   draw_time = time_thing;
   time_format = time_fmt_thing;
   always_load_info = always_load_thing;
-
-  config_update = TRUE;
-  if ((scroll_enable != prev_scroll_enable) || (buttons_enable != prev_buttons_enable))
-    update_gkrellmms_config(0);
-  config_update = FALSE;
 }
 
 void save_gkrellmms_config(FILE *f)
 {
   fprintf(f, "%s scroll_enable %d\n", CONFIG_KEYWORD, scroll_enable);
-  fprintf(f, "%s buttons_enable %d\n", CONFIG_KEYWORD, buttons_enable);
   fprintf(f, "%s xmms_session %d\n", CONFIG_KEYWORD, xmms_session);
   fprintf(f, "%s draw_time %d\n", CONFIG_KEYWORD, draw_time);
   fprintf(f, "%s xmms_autostart %d\n", CONFIG_KEYWORD, xmms_autostart);
   fprintf(f, "%s auto_main_close %d\n", CONFIG_KEYWORD, auto_main_close);
+  fprintf(f, "%s auto_hide_all %d\n", CONFIG_KEYWORD, auto_hide_all);
   fprintf(f, "%s xmms_exec_command %s\n", CONFIG_KEYWORD, xmms_exec_command);
   fprintf(f, "%s files_directory %s\n", CONFIG_KEYWORD, files_directory);
   fprintf(f, "%s playlist_dir %s\n", CONFIG_KEYWORD, playlist_dir);
   fprintf(f, "%s gkrellmms_label %s\n", CONFIG_KEYWORD, gkrellmms_label);
+  fprintf(f, "%s scroll_separator \"%s\"\n", CONFIG_KEYWORD, scroll_separator);
   fprintf(f, "%s eject_opens_playlist %d\n", CONFIG_KEYWORD, eject_opens_playlist);
   fprintf(f, "%s krell_mmb_pause %d\n", CONFIG_KEYWORD, krell_mmb_pause);
   fprintf(f, "%s time_format %d\n", CONFIG_KEYWORD, time_format);
@@ -284,14 +296,14 @@ void load_gkrellmms_config(gchar *arg)
   {
     if (strcmp(config, "scroll_enable") == 0)
       sscanf(item, "%d\n", &scroll_enable);
-    else if (strcmp(config, "buttons_enable") == 0)
-      sscanf(item, "%d\n", &buttons_enable);
     else if (strcmp(config, "xmms_session") == 0)
       sscanf(item, "%d\n", &xmms_session);
     else if (strcmp(config, "xmms_autostart") == 0)
       sscanf(item, "%d\n", &xmms_autostart);
     else if (strcmp(config, "auto_main_close") == 0)
       sscanf(item, "%d\n", &auto_main_close);
+    else if (strcmp(config, "auto_hide_all") == 0)
+      sscanf(item, "%d\n", &auto_hide_all);
     else if (strcmp(config, "eject_opens_playlist") == 0)
       sscanf(item, "%d\n", &eject_opens_playlist);
     else if (strcmp(config, "draw_time") == 0)
@@ -314,25 +326,39 @@ void load_gkrellmms_config(gchar *arg)
       g_free(gkrellmms_label);
       gkrellmms_label = g_strdup(command);
     }
+    else if (strcmp(config, "scroll_separator") == 0)
+    {
+         glong sprt_str, sprt_len; 
+         gchar *scroll_temp = item;
+
+         sprt_str = 0;
+         while (item[sprt_str] != '"') sprt_str++; sprt_str++;
+
+         sprt_len = sprt_str;
+         while (item[sprt_len] != '"') sprt_len++;
+         sprt_len = sprt_len - sprt_str;
+         
+         scroll_separator = malloc(sizeof(char) * (sprt_len + 1));
+         memset(scroll_separator, '\0', sprt_len + 1);
+         scroll_temp += sprt_str;
+         memcpy(scroll_separator, scroll_temp, sprt_len);
+    }
     else if (strcmp(config, "xmms_exec_command") == 0)
     {
-      sscanf(item, "%s\n", command);
-      g_free(xmms_exec_command);
-      xmms_exec_command = g_strdup(command);
+      xmms_exec_command = g_strdup(item);
     }
     else if (strcmp(config, "playlist_dir") == 0)
     {
-      sscanf(item, "%s\n", command);
-      g_free(playlist_dir);
-      playlist_dir = g_strdup(command);
+      playlist_dir = g_strdup(item);
     }
     else if (strcmp(config, "files_directory") == 0)
     {
-      sscanf(item, "%s\n", command);
-      g_free(files_directory);
-      files_directory = g_strdup(command);
+      files_directory = g_strdup(item);
     }
   }
+
+  if(!gkrellm_get_gkrellmrc_integer("gkrellmms_show_buttons",&enable_buttonbar))
+    enable_buttonbar = TRUE;
 }
 
 void eject_type_set(GtkWidget *w, gpointer data)
@@ -369,7 +395,6 @@ void create_gkrellmms_config(GtkWidget *tab)
             *zbox,
             *label,
             *info_label,
-            *info_window,
             *text,
             *eject_entry,
             *time_draw_entry,
@@ -382,9 +407,10 @@ void create_gkrellmms_config(GtkWidget *tab)
          *time_fmt_group = NULL,
          *always_load_group = NULL;
   gchar *gkrellmms_info_text = NULL;
+  gint i;
   static gchar *gkrellmms_help_text[] =
   {
-    "GKrellMMS is a GKrellM XMMS-plugin which allows you to control \n" \
+    N_("GKrellMMS is a GKrellM XMMS-plugin which allows you to control \n" \
     "XMMS from within GKrellM. It features some cool things, such as: \n" \
     "\n" \
     "- A scrolling title. \n" \
@@ -392,133 +418,139 @@ void create_gkrellmms_config(GtkWidget *tab)
     "- Themeable buttons for controlling XMMS. \n" \
     "- A playlist editor. \n" \
     "- A gtk-popup-menu with misc. XMMS-functions. \n" \
-    "\n",
+    "\n"),
 
-    "<b>How to use GKrellMMS: \n",
-    "\n" \
+    N_("<b>How to use GKrellMMS: \n"),
+    N_("\n" \
     "You can do some cool stuff with the XMMS-Krell, by using your mouse. \n" \
-    "\n",
+    "\n"),
 
-    "<b>Mouse actions: \n" \
-    "\n\tLeft mouse-button: ",
-    "Jump through song. \n",
+    N_("<b>Mouse actions: \n" \
+    "\n\tLeft mouse-button: "),
+    N_("Jump through song. \n"),
 
-    "<b>\tMiddle mouse-button: ",
-    "Pause/stop/play XMMS (configurable), \n" \
-    "\t  or launch XMMS if it's not running. \n",
+    N_("<b>\tMiddle mouse-button: "),
+    N_("Pause/stop/play XMMS (configurable), \n" \
+    "\t  or launch XMMS if it's not running. \n"),
 
-    "<b>\tRight mouse-button: ",
-    "Popup-menu. \n" \
+    N_("<b>\tRight mouse-button: "),
+    N_("Popup-menu. \n" \
     "\n" \
     "The led indicator on the Krell indicates several things: \n" \
-    "\n",
+    "\n"),
 
-    "<b>\tConstant red: ",
-    "XMMS is turned off. \n",
+    N_("<b>\tConstant red: "),
+    N_("XMMS is turned off. \n"),
 
-    "<b>\tConstant green: ",
-    "XMMS is playing. \n",
+    N_("<b>\tConstant green: "),
+    N_("XMMS is playing. \n"),
 
-    "<b>\tRed, blinking green: ",
-    "XMMS is stopped. \n",
+    N_("<b>\tRed, blinking green: "),
+    N_("XMMS is stopped. \n"),
 
-    "<b>\tGreen, blinking red: ",
-    "XMMS is paused. \n" \
-    "\n",
+    N_("<b>\tGreen, blinking red: "),
+    N_("XMMS is paused. \n" \
+    "\n"),
 
-    "<b>Configurabilities:\n",
-    "\n" \
+    N_("<b>Configurabilities:\n"),
+    N_("\n" \
     "GKrellM has some configurabilities for if you like to \n" \
     "configure some stuff:\n" \
-    "\n",
+    "\n"),
 
-    "<b>Configs tab: \n" \
+    N_("<b>Configs tab: \n" \
     "\n" \
-    "\tXMMS Executable: \n",
+    "\tXMMS Executable: \n"),
 
-    "\tHow the XMMS-executable (+ eventually path) \n" \
+    N_("\tHow the XMMS-executable (+ eventually path) \n" \
     "\tis called on your computer. Default is xmms\n" \
-    "\n",
+    "\n"),
 
-    "<b>\tFiles Directory: \n",
-    "\tThe directory where your mp3's/xm's/whatever \n" \
+    N_("<b>\tFiles Directory: \n"),
+    N_("\tThe directory where your mp3's/xm's/whatever \n" \
     "\tare stored in. When starting XMMS from GKrellM, it will go to this \n" \
     "\tdirectory when ejecting. \n" \
-    "\n",
+    "\n"),
   
-    "<b>\tPlaylist Directory: \n",
-    "\tThe directory where your m3u-files are stored in. \n" \
-    "\n",
+    N_("<b>\tPlaylist Directory: \n"),
+    N_("\tThe directory where your m3u-files are stored in. \n" \
+    "\n"),
 
-    "<b>\tKrell label: \n",
-    "\tThe text-label you want in the krell when xmms isn't running/playing. \n" \
-    "\n",
+    N_("<b>\tKrell label: \n"),
+    N_("\tThe text-label you want in the krell when xmms isn't running/playing. \n" \
+    "\n"),
   
-    "<b>\tXMMS Session to use: \n",
-    "\tThe XMMS-session you want to use with GKrellMMS. \n" \
+    N_("<b>\tScroll separator: \n"),
+    N_("\tThe little text that will be appended at the end of the scrolled text. \n" \
+    "\tIt defaults to '   ***   ' (that's 3 spaces, 3 *'s and 3 spaces). \n" \
+    "\n"),
+
+    N_("<b>\tXMMS Session to use: \n"),
+    N_("\tThe XMMS-session you want to use with GKrellMMS. \n" \
     "\tUse 0 if you only have 1 XMMS running. \n" \
-    "\n",
+    "\n"),
   
-    "<b>Toggles tab: \n" \
+    N_("<b>Toggles tab: \n" \
     "\n" \
-    "\tDraw minus (-) with remaining time: \n",
+    "\tDraw minus (-) with remaining time: \n"),
   
-    "\tDraw a minus (-) before the remaining time, when you have \n" \
-    "\tthe output-time displaying remaining time. \n\n",
+    N_("\tDraw a minus (-) before the remaining time, when you have \n" \
+    "\tthe output-time displaying remaining time. \n\n"),
 
-    "<b>\tXMMS Auto Launch: \n",
-    "\tAuto launch XMMS when starting GKrellMMS. \n" \
-    "\n",
+    N_("<b>\tXMMS Auto Launch: \n"),
+    N_("\tAuto launch XMMS when starting GKrellMMS. \n" \
+    "\n"),
   
-    "<b>\tAuto Mainwindow Close: \n",
-    "\tAutomatically close the XMMS-mainwindow \n" \
+    N_("<b>\tAuto Mainwindow Close: \n"),
+    N_("\tAutomatically close the XMMS-mainwindow \n" \
     "\twhen GKrellMMS starts, and XMMS is already running, or when \n" \
     "\tlaunching XMMS while GKrellMMS runs. This option also enables the \n" \
     "\tmainwindow back when you quit gkrellm (some people really do). \n" \
-    "\n",
+    "\n"),
 
-    "<b>\tAuto seek on XMMS launch: \n",
-    "\tLet GKrellMMS jump to the location you were the \n" \
-    "\tlast time you killed XMMS from within GKrellMMS. \n\n",
+    N_("<b>\tAuto hide all XMMS windows: \n"),
+    N_("\tAutomatically hide all XMMS windows when GKrellMMS starts. \n" \
+     "\n"),
 
-    "<b>\tAuto start playing: \n",
-    "\tAutomatically start playing when launching XMMS. \n\n",
+    N_("<b>\tAuto seek on XMMS launch: \n"),
+    N_("\tLet GKrellMMS jump to the location you were the \n" \
+    "\tlast time you killed XMMS from within GKrellMMS. \n\n"),
 
-    "<b>\tEnable scrolling title: \n",
-    "\tEnable/disable the scrolling title-panel. \n" \
-    "\n",
+    N_("<b>\tAuto start playing: \n"),
+    N_("\tAutomatically start playing when launching XMMS. \n\n"),
+
+    N_("<b>\tEnable scrolling title: \n"),
+    N_("\tEnable/disable the scrolling title-panel. \n" \
+    "\n"),
   
-    "<b>\tEnable buttons: \n",
-    "\tEnable/disable the prev/play/etc. buttons-panel. \n\n",
-
-    "<b>Switches tab: \n" \
+    N_("<b>Switches tab: \n" \
     "\n" \
-    "\tEject opens: \n",
+    "\tEject opens: \n"),
 
-    "\tCheck whether the eject-button on the button-bar opens a \n" \
+    N_("\tCheck whether the eject-button on the button-bar opens a \n" \
     "\tplaylist or an other XMMS-file. \n" \
-    "\n",
+    "\n"),
   
-    "<b>\tMMB on krell click: \n",
-    "\tCheck whether GKrellMMS should pause/continue or \n" \
+    N_("<b>\tMMB on krell click: \n"),
+    N_("\tCheck whether GKrellMMS should pause/continue or \n" \
     "\tstop/play the current song on a MMB-click on the krell. MMB Click will \n" \
     "\talways start playing the song if XMMS isn't playing. \n" \
-    "\n",
+    "\n"),
 
-    "<b>\tLoad file-info: \n",
-    "\tCheck if GKrellMMS should load all the playlist-info at \n" \
+    N_("<b>\tLoad file-info: \n"),
+    N_("\tCheck if GKrellMMS should load all the playlist-info at \n" \
     "\tplaylist-load (Always), or at file-load (On File play only). \n" \
     "\tThis last option is very useful if you don't use the local \n" \
-    "\tplaylist editor, or are playing on a slow network/cdrom. \n\n",
+    "\tplaylist editor, or are playing on a slow network/cdrom. \n\n"),
 
-    "<b>\tDraw in time bar: \n",
-    "\tCheck whether to draw the output time or 'xmms' in \n" \
+    N_("<b>\tDraw in time bar: \n"),
+    N_("\tCheck whether to draw the output time or 'xmms' in \n" \
     "\tthe time-krell panel. \n" \
-    "\n",
+    "\n"),
 
-    "<b>\tOutput time format: \n",
-    "\tDecide whether to draw the elapsed time, or the remaining time \n" \
-    "\tas output-time in the Krell. \n"
+    N_("<b>\tOutput time format: \n"),
+    N_("\tDecide whether to draw the elapsed time, or the remaining time \n" \
+    "\tas output-time in the Krell. \n")
   };
 
   laptop = gtk_notebook_new();
@@ -536,13 +568,15 @@ void create_gkrellmms_config(GtkWidget *tab)
   hbox = gtk_hbox_new(FALSE, 5);
 
   zbox = gtk_vbox_new(FALSE, 0);
-  label = gtk_label_new("XMMS Executable:");
+  label = gtk_label_new(_("XMMS Executable:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, TRUE, FALSE, 0);
-  label = gtk_label_new("Files Directory:");
+  label = gtk_label_new(_("Files Directory:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, TRUE, FALSE, 0);
-  label = gtk_label_new("Playlist Directory:");
+  label = gtk_label_new(_("Playlist Directory:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, TRUE, FALSE, 0);
-  label = gtk_label_new("Krell label:");
+  label = gtk_label_new(_("Krell label:"));
+  gtk_box_pack_start(GTK_BOX(zbox), label, TRUE, FALSE, 0);
+  label = gtk_label_new(_("Scroll separator:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, TRUE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(hbox), zbox, FALSE, FALSE, 0);
   
@@ -566,6 +600,11 @@ void create_gkrellmms_config(GtkWidget *tab)
   gtk_entry_set_text(GTK_ENTRY(label_entry), gkrellmms_label);
   gtk_entry_set_editable(GTK_ENTRY(label_entry), TRUE);
   gtk_box_pack_start(GTK_BOX(zbox), label_entry, TRUE, FALSE, 0);
+
+  separator_entry = gtk_entry_new_with_max_length(MAXLEN_SCROLL_SEPARATOR);
+  gtk_entry_set_text(GTK_ENTRY(separator_entry), scroll_separator);
+  gtk_entry_set_editable(GTK_ENTRY(separator_entry), TRUE);
+  gtk_box_pack_start(GTK_BOX(zbox), separator_entry, TRUE, FALSE, 0);
   
   gtk_box_pack_start(GTK_BOX(hbox), zbox, FALSE, FALSE, 0);
   gtk_container_add(GTK_CONTAINER(vbox), hbox);
@@ -577,11 +616,11 @@ void create_gkrellmms_config(GtkWidget *tab)
   gtk_spin_button_set_digits(GTK_SPIN_BUTTON(session_entry), (guint) 0);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(session_entry), xmms_session);
   gtk_box_pack_start(GTK_BOX(hbox), session_entry, FALSE, FALSE, 0);
-  label = gtk_label_new("XMMS Session to use");
+  label = gtk_label_new(_("XMMS Session to use"));
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
   gtk_container_add(GTK_CONTAINER(vbox), hbox);
 
-  label = gtk_label_new("Configs");
+  label = gtk_label_new(_("Configs"));
   gtk_container_add(GTK_CONTAINER(frame), vbox);
   gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
 
@@ -592,35 +631,36 @@ void create_gkrellmms_config(GtkWidget *tab)
   vbox = gtk_vbox_new(FALSE, 0);
   gtk_container_border_width(GTK_CONTAINER(vbox), 3);
 
-  draw_minus_entry = gtk_check_button_new_with_label("Draw minus (-) when displaying remaining time");
+  draw_minus_entry = gtk_check_button_new_with_label(_("Draw minus (-) when displaying remaining time"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(draw_minus_entry), draw_minus);  
   gtk_container_add(GTK_CONTAINER(vbox), draw_minus_entry);
 
-  xmms_start_entry = gtk_check_button_new_with_label("Auto launch XMMS on GKrellMMS startup");
+  xmms_start_entry = gtk_check_button_new_with_label(_("Auto launch XMMS on GKrellMMS startup"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(xmms_start_entry), xmms_autostart);
   gtk_container_add(GTK_CONTAINER(vbox), xmms_start_entry);
 
-  main_close_entry = gtk_check_button_new_with_label("Auto close (and open) XMMS Mainwin");
+  main_close_entry = gtk_check_button_new_with_label(_("Auto close (and open) XMMS Mainwin"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(main_close_entry), auto_main_close);
   gtk_container_add(GTK_CONTAINER(vbox), main_close_entry);
 
-  auto_seek_entry = gtk_check_button_new_with_label("Auto seek to last location on XMMS launch");
+  hide_all_entry = gtk_check_button_new_with_label(_("Auto hide all XMMS windows on XMMS startup"));
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hide_all_entry), auto_hide_all);
+  gtk_container_add(GTK_CONTAINER(vbox), hide_all_entry);
+
+  auto_seek_entry = gtk_check_button_new_with_label(_("Auto seek to last location on XMMS launch"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(auto_seek_entry), auto_seek);
   gtk_container_add(GTK_CONTAINER(vbox), auto_seek_entry);
   
-  auto_play_entry = gtk_check_button_new_with_label("Auto start playing on XMMS launch");
+  auto_play_entry = gtk_check_button_new_with_label(_("Auto start playing on XMMS launch"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(auto_play_entry), auto_play_start);
   gtk_container_add(GTK_CONTAINER(vbox), auto_play_entry);
 
-  scroll_enable_entry = gtk_check_button_new_with_label("Enable scrolling title panel");
+  scroll_enable_entry = gtk_check_button_new_with_label(_("Enable scrolling title panel"));
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(scroll_enable_entry), scroll_enable);
   gtk_container_add(GTK_CONTAINER(vbox), scroll_enable_entry);
 
-  button_enable_entry = gtk_check_button_new_with_label("Enable buttons panel");
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button_enable_entry), buttons_enable);
-  gtk_container_add(GTK_CONTAINER(vbox), button_enable_entry);
 
-  label = gtk_label_new("Toggles");
+  label = gtk_label_new(_("Toggles"));
   gtk_container_add(GTK_CONTAINER(frame), vbox);
   gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
 
@@ -637,19 +677,19 @@ void create_gkrellmms_config(GtkWidget *tab)
 
   gtk_container_border_width(GTK_CONTAINER(zbox), 10);
 
-  label = gtk_label_new("Eject-button opens:");
+  label = gtk_label_new(_("Eject-button opens:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, FALSE, FALSE, 0);
 
   eject_thing = eject_opens_playlist;
   
-  eject_entry = gtk_radio_button_new_with_label(NULL, "Playlist");
+  eject_entry = gtk_radio_button_new_with_label(NULL, _("Playlist"));
   eject_group = gtk_radio_button_group(GTK_RADIO_BUTTON(eject_entry));
   gtk_box_pack_start(GTK_BOX(zbox), eject_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(eject_entry), eject_opens_playlist);
   gtk_signal_connect(GTK_OBJECT(eject_entry), "pressed",
                      (GtkSignalFunc) eject_type_set, GINT_TO_POINTER(1));
   
-  eject_entry = gtk_radio_button_new_with_label(eject_group, "File(s)");
+  eject_entry = gtk_radio_button_new_with_label(eject_group, _("File(s)"));
   gtk_box_pack_start(GTK_BOX(zbox), eject_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(eject_entry), !eject_opens_playlist);
   gtk_signal_connect(GTK_OBJECT(eject_entry), "pressed",
@@ -663,19 +703,19 @@ void create_gkrellmms_config(GtkWidget *tab)
   zbox = gtk_vbox_new(FALSE, 0);
   gtk_container_border_width(GTK_CONTAINER(zbox), 10);
 
-  label = gtk_label_new("Draw in time bar:");
+  label = gtk_label_new(_("Draw in time bar:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, FALSE, FALSE, 0);
 
   time_thing = draw_time;
   
-  time_draw_entry = gtk_radio_button_new_with_label(NULL, "Output time");
+  time_draw_entry = gtk_radio_button_new_with_label(NULL, _("Output time"));
   time_draw_group = gtk_radio_button_group(GTK_RADIO_BUTTON(time_draw_entry));
   gtk_box_pack_start(GTK_BOX(zbox), time_draw_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(time_draw_entry), draw_time);
   gtk_signal_connect(GTK_OBJECT(time_draw_entry), "pressed",
                      (GtkSignalFunc) time_type_set, GINT_TO_POINTER(1));
 
-  time_draw_entry = gtk_radio_button_new_with_label(time_draw_group, "XMMS-text");
+  time_draw_entry = gtk_radio_button_new_with_label(time_draw_group, _("XMMS-text"));
   gtk_box_pack_start(GTK_BOX(zbox), time_draw_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(time_draw_entry), !draw_time);
   gtk_signal_connect(GTK_OBJECT(time_draw_entry), "pressed",
@@ -693,19 +733,19 @@ void create_gkrellmms_config(GtkWidget *tab)
   zbox = gtk_vbox_new(FALSE, 0);
   gtk_container_border_width(GTK_CONTAINER(zbox), 10);
 
-  label = gtk_label_new("Middle mouse click on krell will:");
+  label = gtk_label_new(_("Middle mouse click on krell will:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, FALSE, FALSE, 0);
 
   pause_thing = krell_mmb_pause;
   
-  pause_entry = gtk_radio_button_new_with_label(NULL, "Pause/Continue song");
+  pause_entry = gtk_radio_button_new_with_label(NULL, _("Pause/Continue song"));
   pause_group = gtk_radio_button_group(GTK_RADIO_BUTTON(pause_entry));
   gtk_box_pack_start(GTK_BOX(zbox), pause_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pause_entry), krell_mmb_pause);
   gtk_signal_connect(GTK_OBJECT(pause_entry), "pressed",
                      (GtkSignalFunc) pause_type_set, GINT_TO_POINTER(1));
 
-  pause_entry = gtk_radio_button_new_with_label(pause_group, "Stop/Play song");
+  pause_entry = gtk_radio_button_new_with_label(pause_group, _("Stop/Play song"));
   gtk_box_pack_start(GTK_BOX(zbox), pause_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pause_entry), !krell_mmb_pause);
   gtk_signal_connect(GTK_OBJECT(pause_entry), "pressed",
@@ -719,19 +759,19 @@ void create_gkrellmms_config(GtkWidget *tab)
   zbox = gtk_vbox_new(FALSE, 0);
   gtk_container_border_width(GTK_CONTAINER(zbox), 10);
 
-  label = gtk_label_new("Output time format:");
+  label = gtk_label_new(_("Output time format:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, FALSE, FALSE, 0);
 
   time_fmt_thing = time_format;
   
-  time_fmt_entry = gtk_radio_button_new_with_label(NULL, "Elapsed time");
+  time_fmt_entry = gtk_radio_button_new_with_label(NULL, _("Elapsed time"));
   time_fmt_group = gtk_radio_button_group(GTK_RADIO_BUTTON(time_fmt_entry));
   gtk_box_pack_start(GTK_BOX(zbox), time_fmt_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(time_fmt_entry), time_format);
   gtk_signal_connect(GTK_OBJECT(time_fmt_entry), "pressed",
                      (GtkSignalFunc) time_fmt_type_set, GINT_TO_POINTER(1));
 
-  time_fmt_entry = gtk_radio_button_new_with_label(time_fmt_group, "Remaining time");
+  time_fmt_entry = gtk_radio_button_new_with_label(time_fmt_group, _("Remaining time"));
   gtk_box_pack_start(GTK_BOX(zbox), time_fmt_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(time_fmt_entry), !time_format);
   gtk_signal_connect(GTK_OBJECT(time_fmt_entry), "pressed",
@@ -749,19 +789,19 @@ void create_gkrellmms_config(GtkWidget *tab)
   zbox = gtk_vbox_new(FALSE, 0);
   gtk_container_border_width(GTK_CONTAINER(zbox), 10);
 
-  label = gtk_label_new("Load file-info:");
+  label = gtk_label_new(_("Load file-info:"));
   gtk_box_pack_start(GTK_BOX(zbox), label, FALSE, FALSE, 0);
 
   always_load_thing = always_load_info;
   
-  always_load_entry = gtk_radio_button_new_with_label(NULL, "Always");
+  always_load_entry = gtk_radio_button_new_with_label(NULL, _("Always"));
   always_load_group = gtk_radio_button_group(GTK_RADIO_BUTTON(always_load_entry));
   gtk_box_pack_start(GTK_BOX(zbox), always_load_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(always_load_entry), always_load_info);
   gtk_signal_connect(GTK_OBJECT(always_load_entry), "pressed",
                      (GtkSignalFunc) load_type_set, GINT_TO_POINTER(1));
 
-  always_load_entry = gtk_radio_button_new_with_label(always_load_group, "On File play only");
+  always_load_entry = gtk_radio_button_new_with_label(always_load_group, _("On File play only"));
   gtk_box_pack_start(GTK_BOX(zbox), always_load_entry, FALSE, FALSE, 0);
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(always_load_entry), !always_load_info);
   gtk_signal_connect(GTK_OBJECT(always_load_entry), "pressed",
@@ -778,43 +818,33 @@ void create_gkrellmms_config(GtkWidget *tab)
 
   gtk_container_add(GTK_CONTAINER(hbox), vbox);
   
-  label = gtk_label_new("Switches");
+  label = gtk_label_new(_("Switches"));
   gtk_container_add(GTK_CONTAINER(frame), hbox);
   gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
   
   
   /* Help */
-  frame = gtk_frame_new(NULL);
-  gtk_container_border_width(GTK_CONTAINER(frame), 3);
+  vbox = gkrellm_gtk_framed_notebook_page(laptop,_("Help"));
+  text = gkrellm_gtk_scrolled_text_view(vbox,NULL,
+      GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 
-  info_window = gtk_scrolled_window_new(NULL, NULL);
-  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(info_window),
-    GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-  gtk_container_add(GTK_CONTAINER(frame), info_window);
-
-  text = gtk_text_new(NULL, NULL);
-
-  gkrellm_add_info_text(text, gkrellmms_help_text,
-    sizeof(gkrellmms_help_text) / sizeof(gchar *));
-  gtk_text_set_editable(GTK_TEXT(text), FALSE);
-  gtk_container_add(GTK_CONTAINER(info_window), text);
-
-  label = gtk_label_new("Help");
-  gtk_notebook_append_page(GTK_NOTEBOOK(laptop), frame, label);
+  for (i=0; i < sizeof(gkrellmms_help_text)/sizeof(gchar *); ++i)
+      gkrellm_gtk_text_view_append(text,_(gkrellmms_help_text[i]));
+  gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
 
   /* About */
   gkrellmms_info_text = g_strdup_printf(
-    "GKrellMMS %d.%d.%d\n" \
+    _("GKrellMMS %d.%d.%d\n" \
     "GKrellM XMMS Plugin\n" \
     "\n" \
-    "Copyright (C) 2000 Sander Klein Lebbink\n" \
-    "sander@cerberus.demon.nl \n" \
+    "Copyright (C) 2000-2002 Sander Klein Lebbink <sander@cerberus.demon.nl>\n"\
+    "Current Maintainer: Sjoerd Simons <sjoerd@luon.net>\n" \
     "http://gkrellm.luon.net/\n" \
     "\n" \
-    "Released under the GNU Public License\n",
+    "Released under the GNU Public License\n"),
     GKRELLMMS_VERSION_MAJOR, GKRELLMMS_VERSION_MINOR, GKRELLMMS_VERSION_REV);
   info_label = gtk_label_new(gkrellmms_info_text);
   g_free(gkrellmms_info_text);
-  label = gtk_label_new("About");
+  label = gtk_label_new(_("About"));
   gtk_notebook_append_page(GTK_NOTEBOOK(laptop), info_label, label);
 }
