@@ -1,7 +1,8 @@
 /*  GKrellMMS: GKrellM XMMS Plugin
- |  Copyright (C) 2000 Sander Klein Lebbink
+ |  Copyright (C) 2000-2002 Sander Klein Lebbink
  |
- |  Author:  Sander Klein Lebbink <sander@cerberus.demon.nl>
+ |  Original Author:  Sander Klein Lebbink <sander@cerberus.demon.nl>
+ |  Current Maintainer: Sjoerd Simons <sjoerd@luon.net>
  |  Latest versions might be found at:  http://gkrellm.luon.net/
  |
  |  This program is free software which I release under the GNU General Public
@@ -18,6 +19,7 @@
  |  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <errno.h>
 #include "gkrellmms.h"
 
 /* Save/load functions */
@@ -25,7 +27,7 @@
 static GtkWidget *pl_open_box;
 static gboolean pl_open;
 
-void save_playlist(gchar *filename, gint warn_tell)
+void save_playlist(const gchar *filename, gint warn_tell)
 {
   FILE *f;
   gint i;
@@ -109,9 +111,9 @@ void set_time_position(gint warn_tell)
       xmms_remote_play(xmms_session);
     if (auto_seek && (pos != 0))
     {
-      timer = localtime(&lt)->tm_sec;
+      timer = time(&lt);
       while (!xmms_remote_is_playing(xmms_session) &&
-        ((localtime(&lt)->tm_sec - timer) < 10))
+        ((time(&lt) - timer) < 10))
       {
         /* Do nothing, wait until xmms really plays;
          | stop waiting after 10 seconds.
@@ -127,16 +129,16 @@ void set_time_position(gint warn_tell)
   }
 }
 
-void save_playlist(gchar *, gint);
+void save_playlist(const gchar *, gint);
 void save_position(gint);
 void update_playlist(void);
 
-void open_playlist(gchar *fn, gint warn_tell)
+void open_playlist(const gchar *fn, gint warn_tell)
 {
   FILE *fp;
   gchar *line, *blugh;
-  gchar **files;
-  gint linelen = 1024, i = 0, blaat = 0;
+  GList *list = NULL, *ptr;
+  gint linelen = 1024, blaat = 0;
   gboolean is_playing = xmms_remote_is_playing(xmms_session);
 
   xmms_remote_stop(xmms_session);
@@ -152,20 +154,27 @@ void open_playlist(gchar *fn, gint warn_tell)
     return;
   }
 
-  files = g_malloc0(linelen * sizeof(gchar *));
   line = g_malloc(linelen);
   blugh = g_malloc(linelen);
-  i = 0;
   while (fgets(blugh, linelen, fp))
   {
     blaat = sscanf(blugh, "%[^\n]", line);
-    if (blaat)
-      files[i++] = strdup(line);
+    if (blaat) {
+      list = g_list_append(list,strdup(line));
+    }
+  }
+  if (errno) {
+    blugh = g_strdup_printf("Error reading playlist:\n%s",strerror(errno));
+    gkrellm_message_window("GKrellMMS Error", blugh, NULL);
+    g_free(blugh);
+    fclose(fp);
+    return;
   }
   fclose(fp);
 
   xmms_remote_playlist_clear(xmms_session);
-  xmms_remote_playlist(xmms_session, files, i, TRUE);
+  xmms_remote_playlist_add(xmms_session, list);
+
   update_playlist();
 
   if (is_playing)
@@ -182,9 +191,13 @@ void open_playlist(gchar *fn, gint warn_tell)
    
   g_free(line);
   g_free(blugh);
-  for (i = 0; i < g_list_length(plist); i++)
-    g_free(files[i]);
-  g_free(files);
+
+  ptr = list;
+  for (ptr = list ; ptr ; ptr = g_list_next(ptr)) {
+    free(ptr->data);
+  }
+
+  g_list_free(list);
 }
  
 void pl_ok_sel (GtkWidget *w, GtkFileSelection *fs)
@@ -199,9 +212,9 @@ void destroy_pl(GtkWidget *w, GtkFileSelection *fs)
   gtk_widget_destroy(pl_open_box);
 }
  
-void pl_open_func (GtkWidget *w, gpointer data)
-{
- 
+void pl_open_func (GtkWidget *w, gpointer data) {
+  char *path;
+
   if (pl_open || !xmms_running)
     return;   
   else
@@ -210,6 +223,13 @@ void pl_open_func (GtkWidget *w, gpointer data)
   chdir(playlist_dir);
 
   pl_open_box = gtk_file_selection_new ("Open Playlist");
+ 
+  path = g_strjoin(NULL,g_get_home_dir(),"/",NULL); 
+
+  gtk_file_selection_set_filename(GTK_FILE_SELECTION(pl_open_box), 
+                                  path
+                                 );
+  g_free(path);
   
   gtk_signal_connect(GTK_OBJECT( GTK_FILE_SELECTION(pl_open_box)->ok_button),
                      "clicked", (GtkSignalFunc) pl_ok_sel, pl_open_box);
@@ -286,8 +306,7 @@ void clear_playlist()
 
 void update_playlist_window(void);
 
-void update_playlist()
-{
+void update_playlist() {
   static playlist_def *templ;
   gint i, len;
   
@@ -296,19 +315,25 @@ void update_playlist()
 
   total_plist_time = 0;
 
+  if (!xmms_remote_is_running(xmms_session)) return;
+
   len = xmms_remote_get_playlist_length(xmms_session);
-  for (i = 0; i < len; i++)
-  {
-    templ = g_malloc(sizeof(playlist_def *));
+  for (i = 0; i < len; i++) {
+    templ = g_malloc(sizeof(playlist_def));
     templ->filename = templ->title = '\0';
 
-    while ((templ->filename == '\0') && xmms_remote_is_running(xmms_session))
+    if (xmms_remote_is_running(xmms_session))
       templ->filename = xmms_remote_get_playlist_file(xmms_session, i);
 
-    if (always_load_info)
-    {
-      while ((templ->title == '\0') && xmms_remote_is_running(xmms_session))
-        templ->title = xmms_remote_get_playlist_title(xmms_session, i);
+    if (templ->filename == NULL) {
+      g_free(templ);
+      /* if NULL was returned rerun */
+      return update_playlist();
+    }
+
+
+    if (always_load_info) {
+      templ->title = xmms_remote_get_playlist_title(xmms_session, i);
       templ->time = xmms_remote_get_playlist_time(xmms_session, i);
       total_plist_time += templ->time;
     } else {
@@ -351,11 +376,7 @@ GtkItemFactory *playlist_menu_factory()
   GtkItemFactory *music_factory;
   GtkAccelGroup *axel;
   axel = gtk_accel_group_new();
-#if ((VERSION_MAJOR>1)||(VERION_MAJOR==1 && VERSION_MINOR==1 && VERSION_REV>3)||(VERSION_MAJOR==1 && VERSION_MINOR>1))
   gtk_window_add_accel_group(GTK_WINDOW(gkrellm_get_top_window()), axel);
-#else
-  gtk_window_add_accel_group(GTK_WINDOW(top_window), axel);
-#endif
     
   music_factory = gtk_item_factory_new(GTK_TYPE_MENU, "<Main>", axel);
 
@@ -396,27 +417,35 @@ void select_row_func(GtkWidget *clist, GdkEventButton *ev, gpointer data)
   }
 }
 
-void update_plist_statusbar(gint i)
+int update_plist_statusbar(gint i)
 {
-  static gchar *status_text;
-  static guint prev_status = -1;
-  static playlist_def *templ;
+  gchar *status_text;
+  guint prev_status = -1;
+  playlist_def *templ = NULL;
+  gchar *title;
   gint total;
+  int ret = FALSE;
 
-  if (g_list_length(plist))
-  {
+  if (g_list_length(plist) > i) {
     templ = (playlist_def *) g_list_nth(plist, i)->data;
 
     total_plist_time -= templ->time;
     templ->time = xmms_remote_get_playlist_time(xmms_session, i);
     total_plist_time += templ->time;
 
-    g_free(templ->title);
-    templ->title = xmms_remote_get_playlist_title(xmms_session, i);
+    title = xmms_remote_get_playlist_title(xmms_session, i);
+    if (title == NULL) {
+      title = g_strdup("");
+    }
+    if (strcmp(title,templ->title)) {
+      g_free(templ->title);
+      templ->title = title;  
+      ret = TRUE;
+    }
   }
 
   if (!pl_window_open)
-    return;
+    return ret;
 
   if (prev_status != -1)
     gtk_statusbar_remove(GTK_STATUSBAR(status), 1, prev_status);
@@ -433,6 +462,7 @@ void update_plist_statusbar(gint i)
     prev_status = gtk_statusbar_push(GTK_STATUSBAR(status), 1, status_text);
     g_free(status_text);
   }
+  return ret;
 }
 
 void update_plist_window_row(gint prev_row, gint row)
@@ -479,7 +509,7 @@ void update_plist_window_row(gint prev_row, gint row)
 void update_playlist_window()
 {
   static gchar *song_info[3] = {"", "", ""};
-  gint i, len, nr_check, info_right;
+  gint i, len, info_right;
   playlist_def *templ;
   GtkAdjustment *v;
 
@@ -491,8 +521,7 @@ void update_playlist_window()
   gtk_clist_freeze(GTK_CLIST(play_clist));
   v = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(scrolled));
   gtk_clist_clear(GTK_CLIST(play_clist));
-  for (i = 0; i < g_list_length(plist); i++)
-  {
+  for (i = 0; i < g_list_length(plist); i++) {
     info_right = 0;
     templ = (playlist_def *) g_list_nth(plist, i)->data;
     song_info[0] = g_strdup_printf("%d.", i + 1);
@@ -514,13 +543,6 @@ void update_playlist_window()
     song_info[2] = g_strdup_printf("%d:%02d",
       len / 60000, (len / 1000) % 60);
     gtk_clist_append(GTK_CLIST(play_clist), song_info);
-    if (i == (g_list_length(plist) - 1))
-    {
-      nr_check = gdk_string_width(GTK_WIDGET(play_clist)->style->font, song_info[0]);
-      gtk_clist_set_column_width(GTK_CLIST(play_clist), 0, nr_check);
-      gtk_clist_set_column_width(GTK_CLIST(play_clist), 1, 245 - nr_check);
-    }
-    g_free(song_info[0]);
     if (info_right)
       song_info[1]--;
     g_free(song_info[1]);
@@ -553,9 +575,9 @@ void pl_open_popup(GtkWidget *w, gpointer data)
     pl_window_open = TRUE;
 
   pl_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_policy(GTK_WINDOW(pl_window), FALSE, FALSE, TRUE);
   gtk_window_set_title(GTK_WINDOW(pl_window), "GKrellMMS Playlist Editor");
-  gtk_window_set_wmclass(GTK_WINDOW(pl_window), "GKrellMMS_playlist", "Gkrellm");
+  gtk_window_set_wmclass(GTK_WINDOW(pl_window), 
+                                          "GKrellMMS_playlist", "Gkrellm");
   gtk_signal_connect(GTK_OBJECT(pl_window), "destroy",
                      GTK_SIGNAL_FUNC(pl_window_destroy), (gpointer) pl_window);
   
@@ -566,18 +588,18 @@ void pl_open_popup(GtkWidget *w, gpointer data)
   scrolled = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled),
                                  GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
-  gtk_widget_set_usize(GTK_WIDGET(scrolled), 320, 500);
   gtk_container_border_width(GTK_CONTAINER(scrolled), 2);
   gtk_box_pack_start(GTK_BOX(vbox), scrolled, TRUE, TRUE, 0);
   gtk_widget_show(scrolled);
 
   play_clist = gtk_clist_new_with_titles(3, titles);
+  gtk_clist_set_column_min_width(GTK_CLIST(play_clist),1,230);
   gtk_clist_set_shadow_type(GTK_CLIST(play_clist), GTK_SHADOW_OUT);
   
-  gtk_clist_set_column_width(GTK_CLIST(play_clist), 0, 15);
-  gtk_clist_set_column_width(GTK_CLIST(play_clist), 1, 230);
-
   gtk_clist_set_column_justification(GTK_CLIST(play_clist), 2, GTK_JUSTIFY_RIGHT);
+  gtk_clist_set_column_resizeable(GTK_CLIST(play_clist),1,TRUE);
+  gtk_clist_set_column_resizeable(GTK_CLIST(play_clist),2,TRUE);
+  gtk_clist_set_column_resizeable(GTK_CLIST(play_clist),3,FALSE);
 
   gtk_clist_set_selection_mode(GTK_CLIST(play_clist), GTK_SELECTION_BROWSE);
   gtk_signal_connect(GTK_OBJECT(play_clist), "button_press_event",
@@ -586,33 +608,33 @@ void pl_open_popup(GtkWidget *w, gpointer data)
   gtk_container_add(GTK_CONTAINER(scrolled), play_clist);
   gtk_widget_show(play_clist);
 
-  hbox = gtk_hbox_new(FALSE, 0);
+  hbox = gtk_hbox_new(FALSE, 3);
   open_button = gtk_button_new_with_label("Open Playlist");
-  gtk_box_pack_start(GTK_BOX(hbox), open_button, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), open_button, FALSE, FALSE, 0);
   gtk_signal_connect_object(GTK_OBJECT(open_button), "clicked",
                             GTK_SIGNAL_FUNC(pl_open_func),
                             NULL);
   gtk_widget_show(open_button);
 
   save_button = gtk_button_new_with_label("Save Playlist");
-  gtk_box_pack_start(GTK_BOX(hbox), save_button, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), save_button, FALSE, FALSE, 0);
   gtk_signal_connect_object(GTK_OBJECT(save_button), "clicked",
                             GTK_SIGNAL_FUNC(pl_save_func),
                             NULL);
   gtk_widget_show(save_button);
 
   refresh_button = gtk_button_new_with_label("Force reload");
-  gtk_box_pack_start(GTK_BOX(hbox), refresh_button, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(hbox), refresh_button, FALSE, FALSE, 0);
   gtk_signal_connect_object(GTK_OBJECT(refresh_button), "clicked",
                             GTK_SIGNAL_FUNC(update_playlist),
                             NULL);
   gtk_widget_show(refresh_button);
 
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show(hbox);
 
   status = gtk_statusbar_new();
-  gtk_box_pack_start(GTK_BOX(vbox), status, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(vbox), status, FALSE, FALSE, 0);
   gtk_widget_show(status);
 
   gtk_widget_show(pl_window);
